import json
import xerox
from .pyxhook import HookManager
from .gui import clipboard

# clipboard
clips = []
# number of active clix GUIs 
active = 0
# previos logged key
prev_Key = None

def OnKeyPress(event):
	global prev_Key, active
	if event.Key == 'space' and prev_Key == 'Control_L' and active == 0:
		active = 1
		clipboard(clips)
		active = 0
		prev_Key = None
	elif event.Key == 'c' and prev_Key == 'Control_L':
		text = xerox.paste(xsel = True)
		clips.append(text)
		print("You just copied: {}".format(text))
	else:
		prev_Key = event.Key

def main():
	new_hook = HookManager()
	new_hook.KeyDown = OnKeyPress
	new_hook.HookKeyboard()
	new_hook.start()


if __name__ == "__main__":
	main()
	




# -*- coding: utf-8 -*-
from setuptools import setup

def readme():
	try:
		with open('README.rst') as f:
			return f.read()
	except:
		pass

setup(name = 'clix',
	  version = '1.0.1',
	  classifiers = [
	  	'Development Status :: 4 - Beta',
	  	'License :: OSI Approved :: MIT License',
	  	'Programming Language :: Python',
		'Programming Language :: Python :: 2',
		'Programming Language :: Python :: 2.6',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.3',
		'Programming Language :: Python :: 3.4',
		'Programming Language :: Python :: 3.5',
	  ],
	  keywords = 'clipboard manager tkinter gui desktop',
	  description = 'an easy to use clipboard manager made using tkinter.',
	  long_description = readme(),
	  url = 'https://github.com/nikhilkumarsingh/clix',
	  author = 'Nikhil Kumar Singh',
	  author_email = 'nikhilksingh97@gmail.com',
	  license = 'MIT',
	  packages = ['clix'],
	  install_requires = ['xerox'],
	  include_package_data = True,
	  entry_points="""
	  [console_scripts]
	  clix = clix.clix:main
	  """,
	  zip_safe = False)
